import { ElementRef, ChangeDetectorRef, Inject, Component, Input, Optional, NgModule } from '@angular/core';
import { __spread } from 'tslib';

var Icons = /** @class */ (function () {
    function Icons(icons) {
        this.icons = icons;
    }
    return Icons;
}());

function uppercamelcase(str) {
    return str.toLowerCase().replace(/(?:^\w|[A-Z]|\b\w)/g, function (firstLetter) {
        return firstLetter.toUpperCase();
    }).replace(/[-_]/g, '');
}

var BootstrapIcons = /** @class */ (function () {
    function BootstrapIcons(elem, changeDetector, icons) {
        this.elem = elem;
        this.changeDetector = changeDetector;
        this.icons = icons;
    }
    BootstrapIcons.prototype.ngOnChanges = function (changes) {
        // icons are provided as an array of objects because of "multi: true"
        var icons = Object.assign.apply(Object, __spread([{}], this.icons));
        var svg = icons[uppercamelcase(changes.name.currentValue)] || '';
        if (!svg) {
            console.warn("Icon not found: " + changes.name.currentValue + "\n" +
                "Refer to documentation on https://github.com/biutas/ng-bootstrap-icons/issues");
        }
        this.elem.nativeElement.innerHTML = svg;
        this.changeDetector.markForCheck();
    };
    BootstrapIcons.ctorParameters = function () { return [
        { type: ElementRef },
        { type: ChangeDetectorRef },
        { type: Icons, decorators: [{ type: Inject, args: [Icons,] }] }
    ]; };
    BootstrapIcons.decorators = [
        { type: Component, args: [{
                    // tslint:disable-next-line:component-selector
                    selector: 'bt-icon, bootstrap-icon, bi',
                    template: "<ng-content></ng-content>\r\n",
                    styles: [":host{display:inline-block;width:24px;height:24px;fill:none;stroke-linecap:round;stroke-linejoin:round}:host svg{width:100%!important;height:100%!important}"]
                },] }
    ];
    BootstrapIcons.ctorParameters = function () { return [
        { type: ElementRef },
        { type: ChangeDetectorRef },
        { type: Icons, decorators: [{ type: Inject, args: [Icons,] }] }
    ]; };
    BootstrapIcons.propDecorators = {
        name: [{ type: Input }]
    };
    return BootstrapIcons;
}());

var BootstrapIconsModule = /** @class */ (function () {
    function BootstrapIconsModule(icons) {
        this.icons = icons;
        if (!this.icons) {
            throw new Error("No icon provided. Make sure to use 'BootstrapIconsModule.pick({ ... })' when importing the module\n" +
                "Refer to documentation on https://github.com/biutas/ng-bootstrap-icons/issues");
        }
    }
    BootstrapIconsModule.pick = function (icons) {
        return {
            ngModule: BootstrapIconsModule,
            providers: [{ provide: Icons, multi: true, useValue: icons }],
        };
    };
    BootstrapIconsModule.ctorParameters = function () { return [
        { type: Icons, decorators: [{ type: Optional }] }
    ]; };
    BootstrapIconsModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [BootstrapIcons],
                    exports: [BootstrapIcons],
                },] }
    ];
    BootstrapIconsModule.ctorParameters = function () { return [
        { type: Icons, decorators: [{ type: Optional }] }
    ]; };
    return BootstrapIconsModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { BootstrapIconsModule, BootstrapIcons as ɵa, Icons as ɵb };
//# sourceMappingURL=ng-bootstrap-icons.js.map
